@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -199,6 +199,8 @@ yvi_html_uri_selected_cb (YelpHtml      *html,
 	d(g_print ("Index View: uri selected: %s\n", 
 		   yelp_uri_to_string (uri)));
 
+	g_print ("INDEX: uri_selected_cb\n");
+	
 	g_signal_emit (view, signals[URI_SELECTED], 0, uri, handled);
 }
 
@@ -424,7 +426,7 @@ yelp_view_index_show_uri (YelpViewIndex  *view,
 	priv = view->priv;
 
 	/* FIXME: Handle the GError */
-	yelp_html_open_uri (priv->html_view, uri, error);
+/* 	yelp_html_open_uri (priv->html_view, uri, error); */
 }
 
 /**
